==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Points/Gui/Resources/translations/Points_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="+187"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Convert to points...</source>
      <translation>Μετατροπή σε σημεία...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Convert to points</source>
      <translation>Μετατροπή σε σημεία</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location line="-80"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export points...</source>
      <translation>Εξαγωγή σημείων...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Exports a point cloud</source>
      <translation>Εξάγει ένα σύννεφο σημείο</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location line="-51"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Import points...</source>
      <translation>Εισαγωγή σημείων...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Imports a point cloud</source>
      <translation>Εισάγει ένα σύννεφο σημείο</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location line="+245"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Merge point clouds</source>
      <translation type="unfinished">Merge point clouds</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Merge several point clouds into one</source>
      <translation type="unfinished">Merge several point clouds into one</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location line="-49"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cut point cloud</source>
      <translation>Κόψτε το νέφος σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation type="unfinished">Cuts a point cloud with a picked polygon</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location line="-122"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Transform Points</source>
      <translation>Μετασχηματισμός Σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Test to transform a point cloud</source>
      <translation type="unfinished">Test to transform a point cloud</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>Εισαγωγή σημείων ASCII</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Template:</source>
      <translation>Πρότυπο:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Special lines</source>
      <translation>Ειδικές γραμμές</translation>
    </message>
    <message>
      <location line="+42"/>
      <source>First line:</source>
      <translation>Πρώτη γραμμή:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Ignore</source>
      <translation>Παράβλεψη</translation>
    </message>
    <message>
      <location line="-21"/>
      <source>Cluster by lines starting with:</source>
      <translation>Σύμπλεγμα από τις γραμμές που αρχίζουν με:</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Ignore lines starting with:</source>
      <translation>Αγνοήστε τις γραμμές που αρχίζουν με:</translation>
    </message>
    <message>
      <location line="+54"/>
      <source>Point format</source>
      <translation>Μορφή σημείου</translation>
    </message>
    <message>
      <location line="+78"/>
      <source>Number separator:</source>
      <translation>Διαχωριστικό αριθμού:</translation>
    </message>
    <message>
      <location line="+98"/>
      <source>Points format:</source>
      <translation>Μορφή σημείων:</translation>
    </message>
    <message>
      <location line="-91"/>
      <location line="+7"/>
      <location line="+7"/>
      <source>Next block:</source>
      <translation>Επόμενο μπλοκ:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location line="-147"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>none</source>
      <translation>κανένα</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,J,K (normal vector)</source>
      <translation type="unfinished">I,J,K (normal vector)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,K (normal vector 2D)</source>
      <translation type="unfinished">I,K (normal vector 2D)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>R,G,B (color)</source>
      <translation>R, G, B (χρώμα)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I (Gray value)</source>
      <translation type="unfinished">I (Gray value)</translation>
    </message>
    <message>
      <location line="+61"/>
      <source>Preview</source>
      <translation>Προεπισκόπηση</translation>
    </message>
    <message>
      <location line="+34"/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location line="-238"/>
      <source>Number of points</source>
      <translation>Αριθμός σημείων</translation>
    </message>
    <message>
      <location line="+231"/>
      <source>Number of previewed lines:</source>
      <translation type="unfinished">Number of previewed lines:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation type="unfinished">Ascii Points (*.asc);;All Files (*.*)</translation>
    </message>
    <message>
      <source>Ascii Points</source>
      <translation type="unfinished">Ascii Points</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-76"/>
      <location line="+50"/>
      <source>All Files</source>
      <translation type="unfinished">All Files</translation>
    </message>
    <message>
      <location line="-50"/>
      <location line="+50"/>
      <source>Point formats</source>
      <translation type="unfinished">Point formats</translation>
    </message>
    <message>
      <location line="+71"/>
      <source>Distance</source>
      <translation type="unfinished">Distance</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Enter maximum distance:</source>
      <translation type="unfinished">Enter maximum distance:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Εργαλεία σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Points</source>
      <translation type="unfinished">&amp;Points</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Points/Gui/Resources/translations/Points_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="+188"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Convert to points...</source>
      <translation>Μετατροπή σε σημεία...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Convert to points</source>
      <translation>Μετατροπή σε σημεία</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location line="-80"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export points...</source>
      <translation>Εξαγωγή σημείων...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Exports a point cloud</source>
      <translation>Πραγματοποιεί εξαγωγή ενός νέφους σημείων</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location line="-51"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Import points...</source>
      <translation>Εισαγωγή σημείων...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Imports a point cloud</source>
      <translation>Πραγματοποιεί εισαγωγή ενός νέφους σημείων</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location line="+249"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Merge point clouds</source>
      <translation>Συγχώνευση νεφών σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Merge several point clouds into one</source>
      <translation>Συγχώνευση διαφόρων νεφών σημείων σε ένα</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location line="-49"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cut point cloud</source>
      <translation>Περικοπή νέφους σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Περικόπτει ένα νέφος σημείων με ένα επιλεγμένο πολύγωνο</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location line="-126"/>
      <source>Points</source>
      <translation>Σημεία</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Transform Points</source>
      <translation>Μετασχηματισμός Σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Test to transform a point cloud</source>
      <translation>Δοκιμή μετασχηματισμού ενός νέφους σημείων</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>Εισαγωγή σημείων ASCII</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Template:</source>
      <translation>Πρότυπο:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Special lines</source>
      <translation>Ειδικές γραμμές</translation>
    </message>
    <message>
      <location line="+42"/>
      <source>First line:</source>
      <translation>Πρώτη γραμμή:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Ignore</source>
      <translation>Παράβλεψη</translation>
    </message>
    <message>
      <location line="-21"/>
      <source>Cluster by lines starting with:</source>
      <translation>Σύμπλεγμα από γραμμές που αρχίζουν με:</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Ignore lines starting with:</source>
      <translation>Αγνοήστε γραμμές που αρχίζουν με:</translation>
    </message>
    <message>
      <location line="+54"/>
      <source>Point format</source>
      <translation>Μορφή σημείου</translation>
    </message>
    <message>
      <location line="+78"/>
      <source>Number separator:</source>
      <translation>Διαχωριστικό αριθμού:</translation>
    </message>
    <message>
      <location line="+98"/>
      <source>Points format:</source>
      <translation>Μορφή σημείων:</translation>
    </message>
    <message>
      <location line="-91"/>
      <location line="+7"/>
      <location line="+7"/>
      <source>Next block:</source>
      <translation>Επόμενο μπλοκ:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>;</source>
      <translation>·</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location line="-147"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>none</source>
      <translation>κανένα</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (κάθετο διάνυσμα)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (κάθετο διάνυσμα στον Δισδιάστατο Χώρο)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (χρώμα)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I (Gray value)</source>
      <translation>I (Τιμή του γκρι)</translation>
    </message>
    <message>
      <location line="+61"/>
      <source>Preview</source>
      <translation>Προεπισκόπηση</translation>
    </message>
    <message>
      <location line="+34"/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location line="-238"/>
      <source>Number of points</source>
      <translation>Αριθμός σημείων</translation>
    </message>
    <message>
      <location line="+231"/>
      <source>Number of previewed lines:</source>
      <translation>Αριθμός των απεικονιζόμενων γραμμών:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation type="unfinished">Ascii Points (*.asc);;All Files (*.*)</translation>
    </message>
    <message>
      <source>Ascii Points</source>
      <translation>Σημεία Ascii</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-76"/>
      <location line="+50"/>
      <source>All Files</source>
      <translation>Όλα τα Αρχεία</translation>
    </message>
    <message>
      <location line="-50"/>
      <location line="+50"/>
      <source>Point formats</source>
      <translation>Μορφές σημείων</translation>
    </message>
    <message>
      <location line="+71"/>
      <source>Distance</source>
      <translation type="unfinished">Distance</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Enter maximum distance:</source>
      <translation>Εισαγωγή μέγιστης απόστασης:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Εργαλεία σημείων</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Points</source>
      <translation>Σημεία</translation>
    </message>
  </context>
</TS>
